/* PageAICategoryCreator - Protected JavaScript
 * Copyright (C) 2025 VoiceLessQ
 * This code is protected by copyright law and is not intended for redistribution.
 */

jQuery(document).ready(function($) {
    // Initialize sortable for settings sections
    if ($('.page-ai-sortable-settings').length) {
        $('.page-ai-sortable-settings').sortable({
            items: '.page-ai-setting-card',
            handle: '.page-ai-card-header',
            placeholder: 'page-ai-sortable-placeholder',
            opacity: 0.7,
            update: function(event, ui) {
                // Update the order in the hidden field
                updateSettingsOrder();
            }
        });
    }

    // Add search functionality for category list
    if ($('.page-ai-category-list').length) {
        // Add search input before the category list
        $('.page-ai-category-selector').prepend('<input type="text" class="page-ai-category-search" placeholder="Search categories...">');

        // Handle search functionality
        $('.page-ai-category-search').on('keyup', function() {
            var searchTerm = $(this).val().toLowerCase();

            $('.page-ai-category-item').each(function() {
                var categoryName = $(this).find('label').text().toLowerCase();
                if (categoryName.indexOf(searchTerm) > -1) {
                    $(this).show();
                } else {
                    $(this).hide();
                }
            });
        });
    }

    // Add search functionality for page list
    if ($('.page-ai-page-list').length) {
        // Add search input before the page list
        $('.page-ai-page-selector').prepend('<input type="text" class="page-ai-page-search" placeholder="Search pages...">');

        // Handle search functionality
        $('.page-ai-page-search').on('keyup', function() {
            var searchTerm = $(this).val().toLowerCase();

            $('.page-ai-page-item').each(function() {
                var pageName = $(this).find('label').text().toLowerCase();
                if (pageName.indexOf(searchTerm) > -1) {
                    $(this).show();
                } else {
                    $(this).hide();
                }
            });
        });
    }

    // Add search functionality for menu list
    if ($('.page-ai-menu-list').length) {
        // Add search input before the menu list
        $('.page-ai-menu-selector').prepend('<input type="text" class="page-ai-menu-search" placeholder="Search menu items...">');

        // Handle search functionality
        $('.page-ai-menu-search').on('keyup', function() {
            var searchTerm = $(this).val().toLowerCase();

            // First hide all menu groups
            $('.page-ai-menu-group').hide();

            // Show menu items that match
            $('.page-ai-menu-item').each(function() {
                var menuItemName = $(this).find('label').text().toLowerCase();
                if (menuItemName.indexOf(searchTerm) > -1) {
                    $(this).show();
                    // Show the parent menu group
                    $(this).closest('.page-ai-menu-group').show();
                } else {
                    $(this).hide();
                }
            });

            // If search is empty, show all menu groups
            if (searchTerm === '') {
                $('.page-ai-menu-group').show();
                $('.page-ai-menu-item').show();
            }
        });
    }

    // Initialize toggle for settings cards
    $('.page-ai-card-header').on('click', function(e) {
        if (!$(e.target).hasClass('page-ai-drag-handle')) {
            $(this).closest('.page-ai-setting-card').toggleClass('page-ai-card-collapsed');
        }
    });

    // Store original selection mode to detect changes
    var originalSelectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

    // Handle selection mode change
    $('input[name="page_ai_categories_options[selection_mode]"]').on('change', function() {
        var newMode = $(this).val();
        var oldMode = originalSelectionMode;

        // If changing from one mode to another, confirm the change
        if (oldMode !== newMode) {
            var confirmMessage = '';

            if (newMode === 'include') {
                confirmMessage = 'Are you sure you want to switch to Include Mode?\n\n' +
                                'This will change how pages are selected for auto-categorization. ' +
                                'Only specifically included pages will receive categories, and others may have their categories removed.\n\n' +
                                'You will need to select which pages to include after switching.';
            } else {
                confirmMessage = 'Are you sure you want to switch to Exclude Mode?\n\n' +
                                'This will change how pages are selected for auto-categorization. ' +
                                'All pages except specifically excluded ones will receive categories.\n\n' +
                                'Your current page selections will be preserved but used differently.';
            }

            if (!confirm(confirmMessage)) {
                // Revert to original selection if user cancels
                $('input[name="page_ai_categories_options[selection_mode]"][value="' + oldMode + '"]').prop('checked', true);
                return;
            }

            // Update the original mode for future changes
            originalSelectionMode = newMode;
        }

        var mode = $(this).val();

        // Toggle visibility of excluded/included pages cards
        if (mode === 'exclude') {
            $('[data-setting-id="excluded_pages"]').show();
            $('[data-setting-id="included_pages"]').hide();
        } else {
            $('[data-setting-id="excluded_pages"]').hide();
            $('[data-setting-id="included_pages"]').show();
        }

        // Update menu items card title and description
        if (mode === 'exclude') {
            $('label[for="page_ai_excluded_menu_items"]').text('Menu Items to Exclude');
            $('.page-ai-menu-selector .description').text('Select menu items that link to pages that should be excluded from automatic category assignment.');
        } else {
            $('label[for="page_ai_excluded_menu_items"]').text('Menu Items to Include');
            $('.page-ai-menu-selector .description').text('Select menu items that link to pages that should be included in automatic category assignment.');
        }
    });

    // Trigger the change event on page load
    $('input[name="page_ai_categories_options[selection_mode]"]:checked').trigger('change');

    // Helper function for bulk action confirmation
    function confirmBulkAction(action, selectionMode) {
        var confirmMessage = '';

        if (selectionMode === 'include') {
            if (action === 'select-all') {
                return true; // No confirmation needed for selecting all in include mode
            } else if (action === 'select-none') {
                confirmMessage = 'Are you sure you want to exclude ALL pages from auto-categorization?\n\n' +
                                'No pages will receive AI-generated categories, and existing categories may be removed.';
            } else if (action === 'select-default') {
                confirmMessage = 'Are you sure you want to only include default WordPress pages for auto-categorization?\n\n' +
                                'Only default pages will receive categories, and other pages may have their categories removed.';
            } else if (action === 'select-non-default') {
                confirmMessage = 'Are you sure you want to exclude default WordPress pages from auto-categorization?\n\n' +
                                'Default pages will not receive categories and may have existing categories removed.';
            }
        } else { // exclude mode
            if (action === 'select-all') {
                confirmMessage = 'Are you sure you want to exclude ALL pages from auto-categorization?\n\n' +
                                'All pages will have their categories removed.';
            } else if (action === 'select-none') {
                return true; // No confirmation needed for deselecting all in exclude mode
            } else if (action === 'select-default') {
                confirmMessage = 'Are you sure you want to exclude all default WordPress pages?\n\n' +
                                'Default pages will have their categories removed.';
            }
        }

        return confirmMessage ? confirm(confirmMessage) : true;
    }

    // Handle select all/none buttons for pages
    $('.page-ai-select-all').on('click', function(e) {
        e.preventDefault();

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Confirm action
        if (confirmBulkAction('select-all', selectionMode)) {
            $(this).closest('.page-ai-page-selector').find('.page-ai-page-list input[type="checkbox"]').prop('checked', true);
        }
    });

    $('.page-ai-select-none').on('click', function(e) {
        e.preventDefault();

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Confirm action
        if (confirmBulkAction('select-none', selectionMode)) {
            $(this).closest('.page-ai-page-selector').find('.page-ai-page-list input[type="checkbox"]').prop('checked', false);
        }
    });

    // Handle select default pages button
    $('.page-ai-select-default').on('click', function(e) {
        e.preventDefault();

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Confirm action
        if (confirmBulkAction('select-default', selectionMode)) {
            $(this).closest('.page-ai-page-selector').find('.page-ai-page-list input[type="checkbox"]').prop('checked', false);
            $(this).closest('.page-ai-page-selector').find('.page-ai-page-default').closest('label').find('input[type="checkbox"]').prop('checked', true);
        }
    });

    // Handle select non-default pages button
    $('.page-ai-select-non-default').on('click', function(e) {
        e.preventDefault();

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Confirm action
        if (confirmBulkAction('select-non-default', selectionMode)) {
            $(this).closest('.page-ai-page-selector').find('.page-ai-page-list input[type="checkbox"]').prop('checked', true);
            $(this).closest('.page-ai-page-selector').find('.page-ai-page-default').closest('label').find('input[type="checkbox"]').prop('checked', false);
        }
    });

    // Handle select all/none buttons for menu items
    $('.page-ai-select-all-menu').on('click', function(e) {
        e.preventDefault();

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Confirm action for exclude mode
        if (selectionMode === 'exclude') {
            if (!confirm('Are you sure you want to exclude ALL menu pages from auto-categorization?\n\nAll menu pages will have their categories removed.')) {
                return;
            }
        }

        $(this).closest('.page-ai-menu-selector').find('.page-ai-menu-list input[type="checkbox"]').prop('checked', true);
    });

    $('.page-ai-select-none-menu').on('click', function(e) {
        e.preventDefault();

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Confirm action for include mode
        if (selectionMode === 'include') {
            if (!confirm('Are you sure you want to exclude ALL menu pages from auto-categorization?\n\nNo menu pages will receive AI-generated categories, and existing categories may be removed.')) {
                return;
            }
        }

        $(this).closest('.page-ai-menu-selector').find('.page-ai-menu-list input[type="checkbox"]').prop('checked', false);
    });

    // Handle confirmation when unchecking a page in include mode
    $(document).on('click', '.page-ai-page-list input[type="checkbox"], .page-ai-menu-list input[type="checkbox"]', function(e) {
        // Only show confirmation when unchecking
        if ($(this).prop('checked')) {
            return;
        }

        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Get the page title
        var pageTitle = $(this).closest('label').text().trim();

        // Different messages based on selection mode
        var confirmMessage = '';

        if (selectionMode === 'include') {
            // In include mode, unchecking means the page won't be categorized
            confirmMessage = 'Are you sure you want to exclude "' + pageTitle + '" from auto-categorization?\n\n' +
                             'This page will no longer receive AI-generated categories, and existing categories may be removed.';
        } else {
            // In exclude mode, unchecking means the page will be categorized
            confirmMessage = 'Are you sure you want to exclude "' + pageTitle + '" from auto-categorization?\n\n' +
                             'Any existing categories on this page will be removed.';
        }

        // Show confirmation dialog
        if (!confirm(confirmMessage)) {
            // If user cancels, prevent the checkbox from being unchecked
            e.preventDefault();
            return false;
        }
    });

    // Initialize the API key toggle
    $('#show-api-key').on('click', function(e) {
        e.preventDefault();
        var apiKeyField = $('#page_ai_api_key');
        if (apiKeyField.attr('type') === 'password') {
            apiKeyField.attr('type', 'text');
            $(this).text('Hide');
        } else {
            apiKeyField.attr('type', 'password');
            $(this).text('Show');
        }
    });

    // Function to update the settings order
    function updateSettingsOrder() {
        var order = [];
        $('.page-ai-setting-card').each(function() {
            order.push($(this).data('setting-id'));
        });
        $('#page_ai_settings_order').val(JSON.stringify(order));
    }

    // Initialize the settings order on page load
    updateSettingsOrder();

    // Add confirmation when submitting the form
    $('form[action="options.php"]').on('submit', function(e) {
        // Get the current selection mode
        var selectionMode = $('input[name="page_ai_categories_options[selection_mode]"]:checked').val();

        // Count selected/deselected pages
        var totalPages = 0;
        var selectedPages = 0;

        if (selectionMode === 'include') {
            // In include mode, count included pages
            totalPages = $('.page-ai-setting-card[data-setting-id="included_pages"] .page-ai-page-item').length;
            selectedPages = $('.page-ai-setting-card[data-setting-id="included_pages"] input[type="checkbox"]:checked').length;
        } else {
            // In exclude mode, count excluded pages
            totalPages = $('.page-ai-setting-card[data-setting-id="excluded_pages"] .page-ai-page-item').length;
            selectedPages = $('.page-ai-setting-card[data-setting-id="excluded_pages"] input[type="checkbox"]:checked').length;
        }

        var confirmMessage = '';

        if (selectionMode === 'include') {
            if (selectedPages === 0) {
                confirmMessage = 'WARNING: You have not selected any pages to include for auto-categorization.\n\n' +
                                'No pages will receive AI-generated categories, and existing categories may be removed from all pages.\n\n' +
                                'Are you sure you want to continue?';
            } else {
                confirmMessage = 'You have selected ' + selectedPages + ' out of ' + totalPages + ' pages to receive AI-generated categories.\n\n' +
                                'Only these selected pages will receive categories. Other pages may have their categories removed.\n\n' +
                                'Are you sure you want to save these settings?';
            }
        } else {
            if (selectedPages === totalPages) {
                confirmMessage = 'WARNING: You have excluded ALL pages from auto-categorization.\n\n' +
                                'No pages will receive AI-generated categories, and existing categories will be removed from excluded pages.\n\n' +
                                'Are you sure you want to continue?';
            } else {
                confirmMessage = 'You have excluded ' + selectedPages + ' out of ' + totalPages + ' pages from auto-categorization.\n\n' +
                                'These excluded pages will have their categories removed. All other pages will receive AI-generated categories.\n\n' +
                                'Are you sure you want to save these settings?';
            }
        }

        // Show confirmation dialog
        if (!confirm(confirmMessage)) {
            e.preventDefault();
            return false;
        }
    });

    // Initialize color pickers
    if ($.fn.wpColorPicker) {
        $('.page-ai-color-picker').wpColorPicker();
    }

    // Initialize tooltips
    $('.page-ai-help-tip').on('click', function(e) {
        e.preventDefault();
        $(this).next('.page-ai-tooltip').toggleClass('page-ai-tooltip-active');
    });

    // Close tooltips when clicking outside
    $(document).on('click', function(e) {
        if (!$(e.target).hasClass('page-ai-help-tip')) {
            $('.page-ai-tooltip').removeClass('page-ai-tooltip-active');
        }
    });
});
